@@ -118,7 +118,8 @@ class OutputChecker(doctest.OutputChecker):
                 else:
                     nw_.append(nw)
 
-                if not np.allclose(float(ng), float(nw), equal_nan=True):
+                if not np.allclose(float(ng), float(nw), rtol=self.rtol,
+                                   atol=self.atol, equal_nan=True):
                     return False
 
             # replace all floats in the "got" string by those from "wanted".
